==> offline-rce-results-module-0.2.6.tar.gz: offline-rce-results-module-0.2.6/offline_results/recommendation/homepage_recommendation/core/with_content_based_filtering/main.py <==
from offline_results.common.constants import GRAPH_DB
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.data_gathering import \
    DataGathering
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.data_preperation import \
    DataPreprocessing
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.generate_recommendation import \
    HomepageIdContentScorePred
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.model_training import \
    RecommendationModel
import logging
logging.basicConfig(level=logging.INFO)


class HomepageIdContentsRecommendation(DataGathering, DataPreprocessing, RecommendationModel, HomepageIdContentScorePred):

    def get_data(self):
        self.data_gathering()

    def data_preparation(self):
        self.preprocessing(self.raw_data)

    def train_model(self):
        try:
            self.get_data()
            self.data_preparation()
            self.create_data_obj()
            model = self.model_training()
            if model is not None:
                self.save_model_to_s3(model)

        except Exception as e:
            logging.error(f"Error while training model. Error :{e}")

#test code here for model training
# if __name__ == "__main__":
#     ctl = HomepageIdContentsRecommendation(data_source=GRAPH_DB) #data_source options are , s3, graph_db
#     ctl.train_model()

##test code here for getting score for content ids
# if __name__ == "__main__":
#     ctl=HomepageIdContentsRecommendation()
#     model = ctl.load_model_from_s3()
#     recomm = ctl.get_score(user=4120, contents=[15, 50, 11, 17173, 34410], model=model)
#     print(recomm)

==> offline-rce-results-module-0.4.19.tar.gz: offline-rce-results-module-0.4.19/offline_results/recommendation/homepage_recommendation/core/with_content_based_filtering/main.py <==
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.data_gathering import \
    DataGathering
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.data_preperation import \
    DataPreprocessing
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.generate_recommendation import \
    HomepageIdContentScorePred
from offline_results.recommendation.homepage_recommendation.core.with_content_based_filtering.model_training import \
    RecommendationModel
import logging
logging.basicConfig(level=logging.INFO)


class HomepageIdContentsRecommendation(DataGathering, DataPreprocessing, RecommendationModel, HomepageIdContentScorePred):

    def get_data(self):
        self.data_gathering()

    def data_preparation(self):
        self.preprocessing(self.raw_data)

    def train_model(self):
        try:
            self.get_data()
            self.data_preparation()
            self.create_data_obj()
            model = self.model_training()
            if model is not None:
                self.save_model_to_s3(model)

        except Exception as e:
            logging.error(f"Error while training model. Error :{e}")

#test code here for model training
# if __name__ == "__main__":
#     ctl = HomepageIdContentsRecommendation(data_source=S3) #data_source options are , s3, graph_db
#     ctl.train_model()

##test code here for getting score for content ids
# if __name__ == "__main__":
#     ctl=HomepageIdContentsRecommendation()
#     model = ctl.load_model_from_s3()
#     recomm = ctl.get_score(user=4120, contents=[15, 50, 11, 17173, 34410], model=model)
#     print(recomm)
